@@ -1,7 +1,7 @@
 from pathlib import Path
 
 from darker.__main__ import modify_file
-from darker.black_diff import BlackArgs, run_black
+from darker.black_diff import BlackConfig, run_black
 from darker.chooser import choose_lines
 from darker.diff import diff_and_get_opcodes, opcodes_to_chunks
 from darker.utils import TextDocument
@@ -18,14 +18,14 @@ def format_file(
     to_line: int,
     config: str = None,
 ):
-    black_args = BlackArgs(config=config)
+    black_args = BlackConfig(config=config)
     edited = worktree_content = TextDocument.from_file(src)
     max_context_lines = len(edited.lines)
     minimum_context_lines = BinarySearch(0, max_context_lines + 1)
     edited_linenums = list(range(from_line, to_line + 1))
 
     while not minimum_context_lines.found:
-        formatted = run_black(src, edited, black_args)
+        formatted = run_black(edited, black_args)
         opcodes = diff_and_get_opcodes(edited, formatted)
         black_chunks = list(opcodes_to_chunks(opcodes, edited, formatted))
         chosen = TextDocument.from_lines(
